@@ -36,7 +36,10 @@ class _IgorInit:
         :param key_residues: multiple entries -see class docstring
         """
         self.pose = pose
-        pyrosetta.create_score_function('ref2015')(pose)
+        # virtualroot
+        if pose.residue(self.pose.total_residue()).name3() != 'XXX':
+            pyrosetta.rosetta.core.pose.addVirtualResAsRoot(self.pose)
+        pyrosetta.create_score_function('ref2015')(self.pose)
         self.constraint_file = constraint_file
         self.ligand_residue = self._parse_residue(ligand_residue)
         self.key_residues = self._parse_key_residues(key_residues)
